@@ -35,6 +35,16 @@ class GenericSubtitle(object):
         eq = eq and self.inner == other.inner
         return eq
 
+    @property
+    def content(self):
+        if isinstance(self.inner, srt.Subtitle):
+            ret = self.inner.content
+        elif isinstance(self.inner, pysubs2.SSAEvent):
+            ret = self.inner.text
+        else:
+            raise NotImplementedError('unsupported subtitle type: %s' % type(self.inner))
+        return ret
+
     def resolve_inner_timestamps(self):
         ret = copy.deepcopy(self.inner)
         if isinstance(self.inner, srt.Subtitle):
@@ -85,6 +95,7 @@ class GenericSubtitlesFile(object):
         self.subs_ = subs
         self._sub_format = sub_format
         self._encoding = encoding
+        self._styles = kwargs.pop('styles', None)
 
     def set_encoding(self, encoding):
         if encoding != 'same':
@@ -105,6 +116,10 @@ class GenericSubtitlesFile(object):
     def encoding(self):
         return self._encoding
 
+    @property
+    def styles(self):
+        return self._styles
+
     def gen_raw_resolved_subs(self):
         for sub in self.subs_:
             yield sub.resolve_inner_timestamps()
@@ -118,7 +133,8 @@ class GenericSubtitlesFile(object):
         return GenericSubtitlesFile(
             offset_subs,
             sub_format=self.sub_format,
-            encoding=self.encoding
+            encoding=self.encoding,
+            styles=self.styles
         )
 
     def write_file(self, fname):
@@ -133,6 +149,7 @@ class GenericSubtitlesFile(object):
         elif out_format in ('ssa', 'ass'):
             ssaf = pysubs2.SSAFile()
             ssaf.events = subs
+            ssaf.styles = self.styles
             to_write = ssaf.to_string(out_format)
         else:
             raise NotImplementedError('unsupported output format: %s' % out_format)
